@@ -38,9 +38,9 @@ import easybuild.tools.environment as env
 import easybuild.tools.toolchain as toolchain
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM
-from easybuild.tools.filetools import run_cmd, run_cmd_qa
 from easybuild.tools.modules import get_software_root
 from easybuild.tools.ordereddict import OrderedDict
+from easybuild.tools.run import run_cmd, run_cmd_qa
 
 
 class EB_ALADIN(EasyBlock):
@@ -158,7 +158,7 @@ class EB_ALADIN(EasyBlock):
             self.log.error("Failed to remove existing file %s: %s" % (self.conf_filepath, err))
 
         mpich = 'n'
-        known_mpi_libs = [toolchain.MPICH2, toolchain.INTELMPI]
+        known_mpi_libs = [toolchain.MPICH, toolchain.MPICH2, toolchain.INTELMPI]
         if self.toolchain.options.get('usempi', None) and self.toolchain.mpi_family() in known_mpi_libs:
             mpich = 'y'
 
@@ -198,28 +198,27 @@ class EB_ALADIN(EasyBlock):
         blaslib = ' '.join(blaslibs)
 
         qa = {
-              'Do you want to run the configuration file maker assistant now (y) or later [n] ?': 'y',
-              'Do you want to setup your configuration file for MPICH (y/n) [n] ?': mpich,
-              'Please type the directory name where to find a dummy file mpif.h or ignore :': os.getenv('MPI_INC_DIR'),
-              '%sthe library gribex or emos%s' % (qpref, qsuff2): aux_lib_gribex,
-              '%sthe library ibm%s' % (qpref, qsuff): aux_lib_ibm,
-              '%sthe library grib_api%s' % (qpref, qsuff): grib_api_lib,
-              '%sthe library grib_api_f90%s' % (qpref, qsuff): grib_api_f90_lib,
-              '%sthe JPEG auxilary library if enabled by Grib_api%s' % (qpref, qsuff2): jasperlib,
-              '%sthe library netcdf%s' % (qpref, qsuff): netcdflib,
-              '%sthe library lapack%s' % (qpref, qsuff): lapacklib,
-              '%sthe library blas%s' % (qpref, qsuff): blaslib,
-              '%sthe library mpi%s' % (qpref, qsuff): mpilib,
-              '%sa MPI dummy library for serial executions, or ignore :' % qpref: '',
-              'Please type the directory name where to find grib_api headers, or ignore :': grib_api_inc,
-              'Please type the directory name where to find fortint.h or ignore :': '',
-              'Please type the directory name where to find netcdf headers, or ignore :': netcdfinc,
-              'Do you want to define CANARI (y/n) [y] ?': 'y',
-              'Please type the name of the script file used to generate a preprocessed blacklist file, or ignore :': '',
-              'Please type the name of the script file used to recover local libraries (gget), or ignore :': '',
-              'Please type the options to tune the gnu compilers, or ignore :': os.getenv('F90FLAGS'),
-
-             }
+            'Do you want to run the configuration file maker assistant now (y) or later [n] ?': 'y',
+            'Do you want to setup your configuration file for MPICH (y/n) [n] ?': mpich,
+            'Please type the directory name where to find a dummy file mpif.h or ignore :': os.getenv('MPI_INC_DIR'),
+            '%sthe library gribex or emos%s' % (qpref, qsuff2): aux_lib_gribex,
+            '%sthe library ibm%s' % (qpref, qsuff): aux_lib_ibm,
+            '%sthe library grib_api%s' % (qpref, qsuff): grib_api_lib,
+            '%sthe library grib_api_f90%s' % (qpref, qsuff): grib_api_f90_lib,
+            '%sthe JPEG auxilary library if enabled by Grib_api%s' % (qpref, qsuff2): jasperlib,
+            '%sthe library netcdf%s' % (qpref, qsuff): netcdflib,
+            '%sthe library lapack%s' % (qpref, qsuff): lapacklib,
+            '%sthe library blas%s' % (qpref, qsuff): blaslib,
+            '%sthe library mpi%s' % (qpref, qsuff): mpilib,
+            '%sa MPI dummy library for serial executions, or ignore :' % qpref: '',
+            'Please type the directory name where to find grib_api headers, or ignore :': grib_api_inc,
+            'Please type the directory name where to find fortint.h or ignore :': '',
+            'Please type the directory name where to find netcdf headers, or ignore :': netcdfinc,
+            'Do you want to define CANARI (y/n) [y] ?': 'y',
+            'Please type the name of the script file used to generate a preprocessed blacklist file, or ignore :': '',
+            'Please type the name of the script file used to recover local libraries (gget), or ignore :': '',
+            'Please type the options to tune the gnu compilers, or ignore :': os.getenv('F90FLAGS'),
+        }
 
         f90_seq = os.getenv('F90_SEQ')
         if not f90_seq:
@@ -227,17 +226,21 @@ class EB_ALADIN(EasyBlock):
             f90_seq = os.getenv('F90')
 
         stdqa = OrderedDict([
-                             (r'Confirm library .* is .*', 'y'),  # this one needs to be tried first!
-                             (r'.*fortran 90 compiler name .*\s*:\n\(suggestions\s*: .*\)', os.getenv('F90')),
-                             (r'.*fortran 90 compiler interfaced with .*\s*:\n\(suggestions\s*: .*\)', f90_seq),
-                             (r'Please type the ABSOLUTE name of .*library.*, or ignore\s*[:]*\s*[\n]*.*', ''),  
-                             (r'Please .* to save this draft configuration file :\n.*', '%s.x' % self.conf_file),
-                            ])
+            (r'Confirm library .* is .*', 'y'),  # this one needs to be tried first!
+            (r'.*fortran 90 compiler name .*\s*:\n\(suggestions\s*: .*\)', os.getenv('F90')),
+            (r'.*fortran 90 compiler interfaced with .*\s*:\n\(suggestions\s*: .*\)', f90_seq),
+            (r'Please type the ABSOLUTE name of .*library.*, or ignore\s*[:]*\s*[\n]*.*', ''),
+            (r'Please .* to save this draft configuration file :\n.*', '%s.x' % self.conf_file),
+        ])
+
+        no_qa = [
+            ".*ignored.",
+        ]
 
         env.setvar('GMKTMP', self.builddir)
         env.setvar('GMKFILE', self.conf_file)
 
-        run_cmd_qa("gmkfilemaker", qa, std_qa=stdqa)
+        run_cmd_qa("gmkfilemaker", qa, std_qa=stdqa, no_qa=no_qa)
 
         # set environment variables for installation dirs
         env.setvar('ROOTPACK', os.path.join(self.installdir, 'rootpack'))
