@@ -33,7 +33,7 @@ import shutil
 
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.tools.modules import get_software_root, get_software_version
-from easybuild.tools.filetools import run_cmd
+from easybuild.tools.run import run_cmd
 
 
 class EB_ant(EasyBlock):
