@@ -33,7 +33,7 @@ EasyBuild support for building and installing Doxygen, implemented as an easyblo
 """
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
-from easybuild.tools.filetools import run_cmd
+from easybuild.tools.run import run_cmd
 
 
 class EB_Doxygen(ConfigureMake):
