@@ -38,7 +38,8 @@ import stat
 
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM
-from easybuild.tools.filetools import run_cmd, rmtree2
+from easybuild.tools.filetools import rmtree2
+from easybuild.tools.run import run_cmd
 
 
 class Binary(EasyBlock):
@@ -50,11 +51,11 @@ class Binary(EasyBlock):
     @staticmethod
     def extra_options(extra_vars=None):
         """Extra easyconfig parameters specific to Binary easyblock."""
-        extra_vars = dict(EasyBlock.extra_options(extra_vars))
+        extra_vars = EasyBlock.extra_options(extra_vars)
         extra_vars.update({
             'install_cmd': [None, "Install command to be used.", CUSTOM],
         })
-        return EasyBlock.extra_options(extra_vars)
+        return extra_vars
 
     def extract_step(self):
         """Move all source files to the build directory"""
@@ -87,15 +88,16 @@ class Binary(EasyBlock):
                 rmtree2(self.installdir)
                 shutil.copytree(self.cfg['start_dir'], self.installdir)
             except OSError, err:
-                self.log.error("Failed to copy %s to %s: %s" % (self.cfg['start_dir'], self.installdir))
+                self.log.error("Failed to copy %s to %s: %s" % (self.cfg['start_dir'], self.installdir, err))
         else:
-            self.log.info("Installing %s using command '%s'..." % (self.name, self.cfg['install_cmd']))
-            run_cmd(self.cfg['install_cmd'], log_all=True, simple=True)
+            cmd = ' '.join([self.cfg['preinstallopts'], self.cfg['install_cmd'], self.cfg['installopts']])
+            self.log.info("Installing %s using command '%s'..." % (self.name, cmd))
+            run_cmd(cmd, log_all=True, simple=True)
 
     def make_module_extra(self):
         """Add the install directory to the PATH."""
 
         txt = super(Binary, self).make_module_extra()
-        txt += self.moduleGenerator.prepend_paths("PATH", [''])
+        txt += self.module_generator.prepend_paths("PATH", [''])
         self.log.debug("make_module_extra added this: %s" % txt)
         return txt
