@@ -36,7 +36,7 @@ import os
 import shutil
 
 from easybuild.framework.easyblock import EasyBlock
-from easybuild.tools.filetools import run_cmd_qa
+from easybuild.tools.run import run_cmd_qa
 
 
 class EB_Maple(EasyBlock):
