@@ -36,7 +36,8 @@ import shutil
 from distutils.version import LooseVersion
 
 from easybuild.framework.easyblock import EasyBlock
-from easybuild.tools.filetools import run_cmd, mkdir
+from easybuild.tools.filetools import mkdir
+from easybuild.tools.run import run_cmd
 
 
 class EB_ParMETIS(EasyBlock):
