@@ -31,7 +31,10 @@ EasyBuild support for building and installing scipy, implemented as an easyblock
 @author: Pieter De Baets (Ghent University)
 @author: Jens Timmerman (Ghent University)
 """
+from distutils.version import LooseVersion
+
 from easybuild.easyblocks.generic.fortranpythonpackage import FortranPythonPackage
+import easybuild.tools.toolchain as toolchain
 
 
 class EB_scipy(FortranPythonPackage):
@@ -43,3 +46,14 @@ class EB_scipy(FortranPythonPackage):
 
         self.testinstall = True
         self.testcmd = "cd .. && python -c 'import numpy; import scipy; scipy.test(verbose=2)'"
+
+    def configure_step(self):
+        """Custom configure step for scipy: set extra installation options when needed."""
+        super(EB_scipy, self).configure_step()
+
+        if LooseVersion(self.version) >= LooseVersion('0.13'):
+            # in recent scipy versions, additional compilation is done in the install step,
+            # which requires unsetting $LDFLAGS
+            if self.toolchain.comp_family() in [toolchain.GCC, toolchain.CLANGGCC]:  # @UndefinedVariable
+                self.cfg.update('preinstallopts', "unset LDFLAGS && ")
+
